pro ssw_register, index, data, oindex, odata, ref_index=ref_index, $
                   ref_map=ref_map, derotate=derotate, drotate=drotate,$
                   clobber=clobber
;
;+
;   Name: ssw_register
;
;   Purpose: co-register 'index,data' pairs using mapping driver, opt w/drotate
;
;   Input Parameters:
;      index, data - index,data pairs containing SSW standards
;
;   Output Parameters:
;      oindex - output index of registered images (ssw tags adjusted)
;      odata  - co-registered data cube
;
;   Keyword Parameters:
;      derotate / drotate (synonyms) - if set, included solar diff rot
;      ref_index - optional reference index (structure or SS pointer)
;      ref_map   - optional reference 'map' (per D.M.Zarro et al package)
; 
;   History:
;      21-August-2000 - S.L.Freeland
;
;   Method:
;     index,data -> maps -> coreg_map -> oindex,odata
;
;   Calls:
;      index2map, coreg_map (via drot_map et al), map2index
;
;
;+

nind=n_elements(index)
nimg=data_chk(data,/nim)
drotate=keyword_set(drotate) or keyword_set(derotate)     ; synonyms

if nind ne nimg or 1-data_chk(index,/struct) then begin 
   box_message,'Required 'index,data' pairs
   return

endif

index2map,index,data,maps

case 1 of 
   data_chk(ref_map,/struct):  
   data_chk(ref_index,/struct): refss=tim2dset(index,ref_index) 
   is_number(ref_index): refss=ref_index
   else: refss=nind/2                        ; ~ midpoint 
endcase

if n_elements(refss) gt 0 then $
   index2map,index(refss), data(*,*,refss), ref_map

comaps=coreg_map(maps,ref_map,drotate=drotate)

map2index,comaps,oindex,odata

return
end

