function sxt_get_grill, index, status, no_normal=no_normal, $
         debug=debug, loud=loud

;+
;   Name: sxt_get_grill
;
;   Purpose: return entrance-era dependent Al.1 Grill file
;
;   Input Parameters:
;      index - sxt index record (usually an SFC index)
;
;   Output Paramters:
;      status - return status  1=ok
;                              0=found one but not in correct era
;                             -1=problem (index not Al.1 for example)
;   History:
;      8-Jan-2000 - S.L.Freeland - break code from sfc_prep 
;                                  (since now may be applied to synthetic SFC)
;
;-
debug=keyword_set(debug)
loud=keyword_set(loud) or debug
no_normal=keyword_set(no_normal)

common sxt_get_grill, lastgfile, lastgrill
if n_elements(lastgfile) eq 0 then lastgfile=''

status=-1
if not required_tags(index,'gen,sxt') then begin 
   box_message,'Need SXT index record...'
   return,bytarr(512,512)   
endif
 
retval=make_array(gt_shape(index,/x),gt_shape(index,/y),/byte)

grill_files=file_list('$DIR_SXT_CALIBRATE','al_grill_*.genx')   
ok=(ssw_time_compare(index,(get_yo_dates(/ent))(1),/later) AND $
     (gt_filta(index) eq 1) and (gt_filtb(index) eq 2) )   AND $
      grill_files(0) ne ''

if ok then begin
    earlier=ssw_time_compare(file2time(grill_files),index,/earlier)
    ss=(reverse(where(earlier,ecnt)))(0)>0
    gfile=grill_files(ss)
    status=([1,2])(ecnt eq 0)
    if loud then begin
      mess=[ 'Using grill file: ' + strsplit(gfile,'/',/last,/tail), $
             (['Normalizing','NOT Normalizing'])(no_normal)]
      if ecnt eq 0 then mess=mess+'Warning: grill is from previous era...'
      box_message,mess
      more,get_info(index,/non)
    endif
    if gfile eq lastgfile then grill=lastgrill else begin
       restgen,file=gfile,grill
       lastgrill=grill
       lastgfile=gfile       
    endelse
    retval=grill*(gt_expdur(index)/([2.668e3,1.]))(no_normal)
endif else box_message,'Problem (not Al.1 or no grill files)
if debug then stop

return,retval
end
